@@ -38,6 +38,9 @@
 #define UNINSTALLED_PLUGINDIR "plugins/removable-devices"
 #define UNINSTALLED_SOURCE "nautilus-sendto-command.c"
 
+#define SOEXT           ("." G_MODULE_SUFFIX)
+#define SOEXT_LEN       (strlen (SOEXT))
+
 enum {
 	COLUMN_ICON,
 	COLUMN_DESCRIPTION,
@@ -76,7 +79,7 @@ struct _NS_ui {
 };
 
 static const GOptionEntry entries[] = {
-	{ G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &filenames, "Movies to index", NULL },
+	{ G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &filenames, "Files to send", "[FILES...]" },
 	{ NULL }
 };
 
@@ -381,7 +384,7 @@ option_changed (GtkComboBox *cb, NS_ui *ui)
 	gtk_label_set_mnemonic_widget (GTK_LABEL (ui->send_to_label), aux->data);
 
 	p = (NstPlugin *) g_list_nth_data (plugin_list, option);
-	supports_dirs = p->info->can_send_directories;
+	supports_dirs = (p->info->capabilities & NAUTILUS_CAPS_SEND_DIRECTORIES);
 
 	if (has_dirs == FALSE || supports_dirs != FALSE) {
 		gboolean toggle;
@@ -446,11 +449,11 @@ set_model_for_options_combobox (NS_ui *ui)
 		gtk_list_store_append (model, &iter);
 		gtk_list_store_set (model, &iter,
 					COLUMN_ICON, pixbuf,
-					COLUMN_DESCRIPTION, _(p->info->description),
+					COLUMN_DESCRIPTION, dgettext(p->info->gettext_package, p->info->description),
 					-1);
 		if (last_used != NULL && !strcmp(last_used, p->info->id)) {
 			option = i;
-			last_used_support_dirs = p->info->can_send_directories;
+			last_used_support_dirs = (p->info->capabilities & NAUTILUS_CAPS_SEND_DIRECTORIES);
 		}
 		i++;
 	}
@@ -617,7 +620,7 @@ nautilus_sendto_plugin_dir_process (const char *plugindir)
 
 				p = g_new0(NstPlugin, 1);
 				module_path = g_module_build_path (plugindir, item);
-				p->module = g_module_open (module_path, G_MODULE_BIND_LAZY);
+				p->module = g_module_open (module_path, 0);
 			        if (!p->module) {
                 			g_warning ("error opening %s: %s", module_path, g_module_error ());
 					g_free (module_path);
@@ -679,20 +682,25 @@ nautilus_sendto_plugin_init (void)
 }
 
 static char *
-escape_ampersands (const char *url)
+escape_ampersands_and_commas (const char *url)
 {
 	int i;
 	char *str, *ptr;
 
-	/* Count the number of ampersands */
+	/* Count the number of ampersands & commas */
 	i = 0;
 	ptr = (char *) url;
 	while ((ptr = strchr (ptr, '&')) != NULL) {
 		i++;
 		ptr++;
 	}
+	ptr = (char *) url;
+	while ((ptr = strchr (ptr, ',')) != NULL) {
+		i++;
+		ptr++;
+	}
 
-	/* No ampersands ? */
+	/* No ampersands or commas ? */
 	if (i == 0)
 		return NULL;
 
@@ -700,12 +708,16 @@ escape_ampersands (const char *url)
 	str = g_malloc0 (strlen (url) - i + 3 * i + 1);
 	ptr = str;
 	for (i = 0; url[i] != '\0'; i++) {
-		if (url[i] != '&') {
-			*ptr++ = url[i];
-		} else {
+		if (url[i] == '&') {
 			*ptr++ = '%';
 			*ptr++ = '2';
 			*ptr++ = '6';
+		} else if (url[i] == ',') {
+			*ptr++ = '%';
+			*ptr++ = '2';
+			*ptr++ = 'C';
+		} else {
+			*ptr++ = url[i];
 		}
 	}
 
@@ -734,7 +746,7 @@ nautilus_sendto_init (void)
 
 		uri = g_filename_to_uri (filename, NULL, NULL);
 		g_free (filename);
-		escaped = escape_ampersands (uri);
+		escaped = escape_ampersands_and_commas (uri);
 
 		if (escaped == NULL) {
 			file_list = g_list_prepend (file_list, uri);
